@@ -1,6 +1,6 @@
 /* GStreamer Editing Services
  *
- * Copyright (C) 2012 Thibault Saunier <thibault.saunier@collabora.com>
+ * Copyright (C) 2012-2015 Thibault Saunier <thibault.saunier@collabora.com>
  * Copyright (C) 2012 Volodymyr Rudyi <vladimir.rudoy@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -87,11 +87,17 @@
 
 #include <gst/gst.h>
 
+GST_DEBUG_CATEGORY_STATIC (ges_asset_debug);
+#undef GST_CAT_DEFAULT
+#define GST_CAT_DEFAULT ges_asset_debug
+
 enum
 {
   PROP_0,
   PROP_TYPE,
   PROP_ID,
+  PROP_PROXY,
+  PROP_PROXY_TARGET,
   PROP_LAST
 };
 
@@ -100,6 +106,7 @@ typedef enum
   ASSET_NOT_INITIALIZED,
   ASSET_INITIALIZING, ASSET_INITIALIZED_WITH_ERROR,
   ASSET_PROXIED,
+  ASSET_NEEDS_RELOAD,
   ASSET_INITIALIZED
 } GESAssetState;
 
@@ -111,11 +118,14 @@ struct _GESAssetPrivate
   GESAssetState state;
   GType extractable_type;
 
-  /* When a asset is proxied, instanciating it will
+  /* When an asset is proxied, instanciating it will
    * return the asset it points to */
   char *proxied_asset_id;
 
-  /* The error that accured when a asset has been initialized with error */
+  GList *proxies;
+  GESAsset *proxy_target;
+
+  /* The error that accured when an asset has been initialized with error */
   GError *error;
 };
 
@@ -190,20 +200,21 @@ _check_and_update_parameters (GType * extractable_type, const gchar * id,
   return real_id;
 }
 
+static gboolean
+start_loading (GESAsset * asset)
+{
+  ges_asset_cache_put (gst_object_ref (asset), NULL);
+  return ges_asset_cache_set_loaded (asset->priv->extractable_type,
+      asset->priv->id, NULL);
+}
+
 static gboolean
 initable_init (GInitable * initable, GCancellable * cancellable,
     GError ** error)
 {
-  gboolean ret;
-  GESAsset *asset = GES_ASSET (initable);
-
-  ges_asset_cache_put (gst_object_ref (asset), NULL);
-  ret = ges_asset_cache_set_loaded (asset->priv->extractable_type,
-      asset->priv->id, NULL);
-
   g_clear_error (error);
 
-  return ret;
+  return start_loading (GES_ASSET (initable));
 }
 
 static void
@@ -310,6 +321,12 @@ ges_asset_get_property (GObject * object, guint property_id,
     case PROP_ID:
       g_value_set_string (value, asset->priv->id);
       break;
+    case PROP_PROXY:
+      g_value_set_object (value, ges_asset_get_proxy (asset));
+      break;
+    case PROP_PROXY_TARGET:
+      g_value_set_object (value, ges_asset_get_proxy_target (asset));
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -329,6 +346,12 @@ ges_asset_set_property (GObject * object, guint property_id,
     case PROP_ID:
       asset->priv->id = g_value_dup_string (value);
       break;
+    case PROP_PROXY:
+      ges_asset_set_proxy (asset, g_value_get_object (value));
+      break;
+    case PROP_PROXY_TARGET:
+      ges_asset_set_proxy (g_value_get_object (value), asset);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -339,6 +362,8 @@ ges_asset_finalize (GObject * object)
 {
   GESAssetPrivate *priv = GES_ASSET (object)->priv;
 
+  GST_DEBUG_OBJECT (object, "finalizing");
+
   if (priv->id)
     g_free (priv->id);
 
@@ -371,12 +396,23 @@ ges_asset_class_init (GESAssetClass * klass)
       "The unic identifier of the asset", NULL,
       G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
+  _properties[PROP_PROXY] =
+      g_param_spec_object ("proxy", "Proxy",
+      "The asset default proxy.", GES_TYPE_ASSET, G_PARAM_READWRITE);
+
+  _properties[PROP_PROXY_TARGET] =
+      g_param_spec_object ("proxy-target", "Proxy target",
+      "The target of a proxy asset.", GES_TYPE_ASSET, G_PARAM_READWRITE);
+
   g_object_class_install_properties (object_class, PROP_LAST, _properties);
 
   klass->start_loading = ges_asset_start_loading_default;
   klass->extract = ges_asset_extract_default;
   klass->request_id_update = ges_asset_request_id_update_default;
   klass->inform_proxy = NULL;
+
+  GST_DEBUG_CATEGORY_INIT (ges_asset_debug, "ges-asset",
+      GST_DEBUG_FG_BLUE | GST_DEBUG_BOLD, "GES Asset");
 }
 
 void
@@ -422,9 +458,14 @@ _free_entries (gpointer entry)
   g_slice_free (GESAssetCacheEntry, entry);
 }
 
+static void
+_gtask_return_error (GTask * task, GError * error)
+{
+  g_task_return_error (task, g_error_copy (error));
+}
 
 static void
-_gtask_return_true (GTask * task)
+_gtask_return_true (GTask * task, gpointer udata)
 {
   g_task_return_boolean (task, TRUE);
 }
@@ -436,7 +477,7 @@ _gtask_return_true (GTask * task)
  *
  * Looks for asset with specified id in cache and it's completely loaded.
  *
- * Returns: (transfer none): The #GESAsset found or %NULL
+ * Returns: (transfer none) (nullable): The #GESAsset found or %NULL
  */
 GESAsset *
 ges_asset_cache_lookup (GType extractable_type, const gchar * id)
@@ -471,9 +512,12 @@ gboolean
 ges_asset_cache_set_loaded (GType extractable_type, const gchar * id,
     GError * error)
 {
-  GList *tmp;
   GESAsset *asset;
   GESAssetCacheEntry *entry = NULL;
+  GList *results = NULL;
+  GFunc user_func = NULL;
+  gpointer user_data = NULL;
+
   LOCK_CACHE;
   if ((entry = _lookup_entry (extractable_type, id)) == NULL) {
     UNLOCK_CACHE;
@@ -488,36 +532,29 @@ ges_asset_cache_set_loaded (GType extractable_type, const gchar * id,
       "callback (Error: %s)", g_type_name (asset->priv->extractable_type),
       g_list_length (entry->results), error ? error->message : "");
 
-  if (error) {
-    GList *results = entry->results;
+  results = entry->results;
+  entry->results = NULL;
 
+  if (error) {
     asset->priv->state = ASSET_INITIALIZED_WITH_ERROR;
     if (asset->priv->error)
       g_error_free (asset->priv->error);
     asset->priv->error = g_error_copy (error);
-    entry->results = NULL;
-    UNLOCK_CACHE;
 
     /* In case of error we do not want to emit in idle as we need to recover
      * if possible */
-    for (tmp = results; tmp; tmp = tmp->next) {
-      g_task_return_error (tmp->data, g_error_copy (error));
-      gst_object_unref (tmp->data);
-    }
-
-    g_list_free (results);
-    return TRUE;
+    user_func = (GFunc) _gtask_return_error;
+    user_data = error;
+    GST_DEBUG_OBJECT (asset, "initialized with error");
   } else {
-    GList *results;
-
     asset->priv->state = ASSET_INITIALIZED;
-    results = entry->results;
-    entry->results = NULL;
-    UNLOCK_CACHE;
-
-    g_list_foreach (results, (GFunc) _gtask_return_true, NULL);
-    g_list_free_full (results, gst_object_unref);
+    user_func = (GFunc) _gtask_return_true;
+    GST_DEBUG_OBJECT (asset, "initialized");
   }
+  UNLOCK_CACHE;
+
+  g_list_foreach (results, user_func, user_data);
+  g_list_free_full (results, g_object_unref);
 
   return TRUE;
 }
@@ -583,9 +620,10 @@ ges_asset_request_id_update (GESAsset * asset, gchar ** proposed_id,
 }
 
 gboolean
-ges_asset_set_proxy (GESAsset * asset, const gchar * new_id)
+ges_asset_try_proxy (GESAsset * asset, const gchar * new_id)
 {
   GESAssetClass *class;
+
   if (g_strcmp0 (asset->priv->id, new_id) == 0) {
     GST_WARNING_OBJECT (asset, "Trying to proxy to itself (%s),"
         " NOT possible", new_id);
@@ -599,9 +637,7 @@ ges_asset_set_proxy (GESAsset * asset, const gchar * new_id)
     return FALSE;
   }
 
-  if (asset->priv->proxied_asset_id)
-    g_free (asset->priv->proxied_asset_id);
-
+  g_free (asset->priv->proxied_asset_id);
   asset->priv->state = ASSET_PROXIED;
   asset->priv->proxied_asset_id = g_strdup (new_id);
 
@@ -609,10 +645,159 @@ ges_asset_set_proxy (GESAsset * asset, const gchar * new_id)
   if (class->inform_proxy)
     GES_ASSET_GET_CLASS (asset)->inform_proxy (asset, new_id);
 
-  GST_DEBUG_OBJECT (asset, "Now proxied to %s", new_id);
+  GST_DEBUG_OBJECT (asset, "Trying to proxy to %s", new_id);
+
   return TRUE;
 }
 
+static gboolean
+_lookup_proxied_asset (const gchar * id, GESAssetCacheEntry * entry,
+    const gchar * asset_id)
+{
+  return !g_strcmp0 (asset_id, entry->asset->priv->proxied_asset_id);
+}
+
+/**
+ * ges_asset_set_proxy:
+ * @asset: The #GESAsset to set proxy on
+ * @proxy: (allow-none): The #GESAsset that should be used as default proxy for @asset or
+ * %NULL if you want to use the currently set proxy. Note that an asset can proxy one and only
+ * one other asset.
+ *
+ * A proxying asset is an asset that can substitue the real @asset. For example if you
+ * have a full HD #GESUriClipAsset you might want to set a lower resolution (HD version
+ * of the same file) as proxy. Note that when an asset is proxied, calling
+ * #ges_asset_request will actually return the proxy asset.
+ *
+ * Returns: %TRUE if @proxy has been set on @asset, %FALSE otherwise.
+ */
+gboolean
+ges_asset_set_proxy (GESAsset * asset, GESAsset * proxy)
+{
+  g_return_val_if_fail (asset == NULL || GES_IS_ASSET (asset), FALSE);
+  g_return_val_if_fail (proxy == NULL || GES_IS_ASSET (proxy), FALSE);
+  g_return_val_if_fail (asset != proxy, FALSE);
+
+  if (!proxy) {
+    if (asset->priv->error) {
+      GST_ERROR_OBJECT (asset,
+          "Proxy was loaded with error (%s), it should not be 'unproxied'",
+          asset->priv->error->message);
+
+      return FALSE;
+    }
+
+    if (asset->priv->proxies) {
+      GESAsset *old_proxy = GES_ASSET (asset->priv->proxies->data);
+
+      GES_ASSET (asset->priv->proxies->data)->priv->proxy_target = NULL;
+      g_object_notify_by_pspec (G_OBJECT (old_proxy),
+          _properties[PROP_PROXY_TARGET]);
+    }
+
+    GST_DEBUG_OBJECT (asset, "%s not proxied anymore", asset->priv->id);
+    asset->priv->state = ASSET_INITIALIZED;
+    g_object_notify_by_pspec (G_OBJECT (asset), _properties[PROP_PROXY]);
+
+    return TRUE;
+  }
+
+  if (asset == NULL) {
+    GHashTable *entries_table;
+    GESAssetCacheEntry *entry;
+
+    entries_table = g_hash_table_lookup (type_entries_table,
+        _extractable_type_name (proxy->priv->extractable_type));
+    entry = g_hash_table_find (entries_table, (GHRFunc) _lookup_proxied_asset,
+        (gpointer) ges_asset_get_id (proxy));
+
+    if (!entry) {
+      GST_DEBUG_OBJECT (asset, "Not proxying any asset");
+      return FALSE;
+    }
+
+    asset = entry->asset;
+    while (asset->priv->proxies)
+      asset = asset->priv->proxies->data;
+  }
+
+  if (proxy->priv->proxy_target) {
+    GST_ERROR_OBJECT (asset,
+        "Trying to use %s as a proxy, but it is already proxying %s",
+        proxy->priv->id, proxy->priv->proxy_target->priv->id);
+  }
+
+  if (g_list_find (proxy->priv->proxies, asset)) {
+    GST_ERROR_OBJECT (asset, "Trying to setup a circular proxying dependency!");
+
+    return FALSE;
+  }
+
+  if (g_list_find (asset->priv->proxies, proxy)) {
+    GST_INFO_OBJECT (asset,
+        "%" GST_PTR_FORMAT " already marked as proxy, moving to first", proxy);
+    GES_ASSET (asset->priv->proxies->data)->priv->proxy_target = NULL;
+    asset->priv->proxies = g_list_remove (asset->priv->proxies, proxy);
+  }
+
+  GST_INFO ("%s is now proxied by %s", asset->priv->id, proxy->priv->id);
+  asset->priv->proxies = g_list_prepend (asset->priv->proxies, proxy);
+  proxy->priv->proxy_target = asset;
+  g_object_notify_by_pspec (G_OBJECT (proxy), _properties[PROP_PROXY_TARGET]);
+
+  asset->priv->state = ASSET_PROXIED;
+  g_object_notify_by_pspec (G_OBJECT (asset), _properties[PROP_PROXY]);
+
+  return TRUE;
+}
+
+/**
+ * ges_asset_list_proxies:
+ * @asset: The #GESAsset to get proxies from
+ *
+ * Returns: (element-type GESAsset) (transfer none): The list of proxies @asset has. Note that the default asset to be
+ * used is always the first in that list.
+ */
+GList *
+ges_asset_list_proxies (GESAsset * asset)
+{
+  g_return_val_if_fail (GES_IS_ASSET (asset), NULL);
+
+  return asset->priv->proxies;
+}
+
+/**
+ * ges_asset_get_proxy:
+ * @asset: The #GESAsset to get currenlty used proxy
+ *
+ * Returns: (transfer none) (nullable): The proxy in use for @asset
+ */
+GESAsset *
+ges_asset_get_proxy (GESAsset * asset)
+{
+  g_return_val_if_fail (GES_IS_ASSET (asset), NULL);
+
+  if (asset->priv->state == ASSET_PROXIED && asset->priv->proxies) {
+    return asset->priv->proxies->data;
+  }
+
+  return NULL;
+}
+
+/**
+ * ges_asset_get_proxy_target:
+ * @proxy: The #GESAsset from which to get the the asset it proxies.
+ *
+ * Returns: (transfer none) (nullable): The #GESAsset that is proxied by @proxy
+ */
+GESAsset *
+ges_asset_get_proxy_target (GESAsset * proxy)
+{
+  g_return_val_if_fail (GES_IS_ASSET (proxy), NULL);
+
+  return proxy->priv->proxy_target;
+}
+
 /* Caution, this method should be used in rare cases (ie: for the project
  * as we can change its ID from a useless one to a proper URI). In most
  * cases you want to update the ID creating a proxy
@@ -741,19 +926,26 @@ ges_asset_request (GType extractable_type, const gchar * id, GError ** error)
           asset = NULL;
           goto done;
         case ASSET_PROXIED:
-          asset =
-              ges_asset_cache_lookup (asset->priv->extractable_type,
-              asset->priv->proxied_asset_id);
-          if (asset == NULL) {
-            GST_ERROR ("Asset against a asset we do not"
+          if (asset->priv->proxies == NULL) {
+            GST_ERROR ("Proxied against an asset we do not"
                 " have in cache, something massively screwed");
 
             goto done;
           }
+
+          asset = asset->priv->proxies->data;
+          while (ges_asset_get_proxy (asset))
+            asset = ges_asset_get_proxy (asset);
+
           break;
+        case ASSET_NEEDS_RELOAD:
+          GST_DEBUG_OBJECT (asset, "Asset in cache and needs reload");
+          start_loading (asset);
+
+          goto done;
         case ASSET_INITIALIZED_WITH_ERROR:
           GST_WARNING_OBJECT (asset, "Initialized with error, not returning");
-          if (error)
+          if (asset->priv->error && error)
             *error = g_error_copy (asset->priv->error);
           asset = NULL;
           goto done;
@@ -856,7 +1048,7 @@ ges_asset_request_async (GType extractable_type,
     real_id = g_strdup (id);
   }
 
-  /* Check if we already have a asset for this ID */
+  /* Check if we already have an asset for this ID */
   asset = ges_asset_cache_lookup (extractable_type, real_id);
   if (asset) {
     GTask *task = g_task_new (asset, NULL, callback, user_data);
@@ -881,17 +1073,25 @@ ges_asset_request_async (GType extractable_type,
           ges_asset_cache_append_task (extractable_type, real_id, task);
 
           goto done;
-        case ASSET_PROXIED:
-          asset =
-              ges_asset_cache_lookup (asset->priv->extractable_type,
-              asset->priv->proxied_asset_id);
-          if (asset == NULL) {
-            GST_ERROR ("Asset proxied against a asset we do not"
-                " have in cache, something massively screwed");
+        case ASSET_PROXIED:{
+          GESAsset *target = ges_asset_get_proxy (asset);
+
+          if (target == NULL) {
+            GST_ERROR ("Asset %s proxied against an asset (%s) we do not"
+                " have in cache, something massively screwed",
+                asset->priv->id, asset->priv->proxied_asset_id);
 
             goto done;
           }
+          asset = target;
           break;
+        }
+        case ASSET_NEEDS_RELOAD:
+          GST_DEBUG_OBJECT (asset, "Asset in cache and needs reload");
+          ges_asset_cache_append_task (extractable_type, real_id, task);
+          GES_ASSET_GET_CLASS (asset)->start_loading (asset, &error);
+
+          goto done;
         case ASSET_INITIALIZED_WITH_ERROR:
           g_task_return_error (task,
               error ? error : g_error_copy (asset->priv->error));
@@ -912,6 +1112,55 @@ done:
     g_free (real_id);
 }
 
+/**
+ * ges_asset_needs_reload
+ * @extractable_type: The #GType of the object that can be extracted from the
+ *  asset to be reloaded.
+ * @id: The identifier of the asset to mark as needing reload
+ *
+ * Sets an asset from the internal cache as needing reload. An asset needs reload
+ * in the case where, for example, we were missing a GstPlugin to use it and that
+ * plugin has been installed, or, that particular asset content as changed
+ * meanwhile (in the case of the usage of proxies).
+ *
+ * Once an asset has been set as "needs reload", requesting that asset again
+ * will lead to it being re discovered, and reloaded as if it was not in the
+ * cache before.
+ *
+ * Returns: %TRUE if the asset was in the cache and could be set as needing reload,
+ * %FALSE otherwise.
+ */
+gboolean
+ges_asset_needs_reload (GType extractable_type, const gchar * id)
+{
+  gchar *real_id;
+  GESAsset *asset;
+  GError *error = NULL;
+
+  real_id = _check_and_update_parameters (&extractable_type, id, &error);
+  if (error) {
+    _unsure_material_for_wrong_id (id, extractable_type, error);
+    real_id = g_strdup (id);
+  }
+
+  asset = ges_asset_cache_lookup (extractable_type, real_id);
+
+  if (real_id) {
+    g_free (real_id);
+  }
+
+  if (asset) {
+    GST_DEBUG_OBJECT (asset,
+        "Asset with id %s switch state to ASSET_NEEDS_RELOAD",
+        ges_asset_get_id (asset));
+    asset->priv->state = ASSET_NEEDS_RELOAD;
+    return TRUE;
+  }
+
+  GST_DEBUG ("Asset with id %s not found in cache", id);
+  return FALSE;
+}
+
 /**
  * ges_asset_get_id:
  * @self: The #GESAsset to get ID from
@@ -1029,3 +1278,20 @@ ges_list_assets (GType filter)
 
   return ret;
 }
+
+/**
+ * ges_asset_get_error:
+ * @self: The asset to retrieve the error from
+ *
+ * Returns: (transfer none) (nullable): The #GError of the asset or %NULL if
+ * the asset was loaded without issue
+ *
+ * Since: 1.8
+ */
+GError *
+ges_asset_get_error (GESAsset * self)
+{
+  g_return_val_if_fail (GES_IS_ASSET (self), NULL);
+
+  return self->priv->error;
+}
