@@ -71,6 +71,12 @@ _sync_element_to_layer_property_float (GESTrackElement * trksrc,
   gfloat value;
 
   parent = ges_timeline_element_get_parent (GES_TIMELINE_ELEMENT (trksrc));
+  if (!parent) {
+    GST_DEBUG_OBJECT (trksrc, "Not in a clip... doing nothing");
+
+    return;
+  }
+
   layer = ges_clip_get_layer (GES_CLIP (parent));
 
   gst_object_unref (parent);
@@ -81,12 +87,12 @@ _sync_element_to_layer_property_float (GESTrackElement * trksrc,
     g_object_set (element, propname, value, NULL);
     GST_DEBUG_OBJECT (trksrc, "Setting %s to %f", propname, value);
 
+
+    gst_object_unref (layer);
   } else {
 
     GST_DEBUG_OBJECT (trksrc, "NOT setting the %s", propname);
   }
-
-  gst_object_unref (layer);
 }
 
 static void
@@ -160,14 +166,29 @@ ges_audio_source_create_element (GESTrackElement * trksrc)
   return topbin;
 }
 
+static void
+ges_audio_source_dispose (GObject * object)
+{
+  GESAudioSource *self = GES_AUDIO_SOURCE (object);
+
+  if (self->priv->capsfilter) {
+    gst_object_unref (self->priv->capsfilter);
+    self->priv->capsfilter = NULL;
+  }
+
+  G_OBJECT_CLASS (ges_audio_source_parent_class)->dispose (object);
+}
+
 static void
 ges_audio_source_class_init (GESAudioSourceClass * klass)
 {
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GESTrackElementClass *track_class = GES_TRACK_ELEMENT_CLASS (klass);
   GESAudioSourceClass *audio_source_class = GES_AUDIO_SOURCE_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GESAudioSourcePrivate));
 
+  gobject_class->dispose = ges_audio_source_dispose;
   track_class->nleobject_factorytype = "nlesource";
   track_class->create_element = ges_audio_source_create_element;
   audio_source_class->create_source = NULL;
