@@ -451,6 +451,8 @@ _add_all_groups (GESFormatter * self)
     GList *lchild;
     PendingGroup *pgroup = tmp->data;
 
+    timeline_add_group (self->timeline, pgroup->group);
+
     for (lchild = ((PendingGroup *) tmp->data)->pending_children; lchild;
         lchild = lchild->next) {
       child = g_hash_table_lookup (priv->containers, lchild->data);
@@ -458,8 +460,6 @@ _add_all_groups (GESFormatter * self)
       GST_DEBUG_OBJECT (tmp->data, "Adding %s child %" GST_PTR_FORMAT " %s",
           (const gchar *) lchild->data, child,
           GES_TIMELINE_ELEMENT_NAME (child));
-      ges_timeline_element_set_timeline (GES_TIMELINE_ELEMENT (pgroup->group),
-          self->timeline);
       ges_container_add (GES_CONTAINER (pgroup->group), child);
     }
   }
