@@ -100,10 +100,15 @@ timeline_context_to_layer      (GESTimeline *timeline, gint offset);
 G_GNUC_INTERNAL void
 timeline_add_group             (GESTimeline *timeline,
                                 GESGroup *group);
-G_GNUC_INTERNAL
-void
+G_GNUC_INTERNAL void
 timeline_remove_group          (GESTimeline *timeline,
                                 GESGroup *group);
+G_GNUC_INTERNAL void
+timeline_emit_group_added      (GESTimeline *timeline,
+                                GESGroup *group);
+G_GNUC_INTERNAL void
+timeline_emit_group_removed    (GESTimeline * timeline,
+                                GESGroup * group, GPtrArray * array);
 
 G_GNUC_INTERNAL
 gboolean
@@ -118,9 +123,6 @@ G_GNUC_INTERNAL
 void
 timeline_fill_gaps            (GESTimeline *timeline);
 
-G_GNUC_INTERNAL GList *
-timeline_get_groups           (GESTimeline * timeline);
-
 G_GNUC_INTERNAL
 void
 track_resort_and_fill_gaps    (GESTrack *track);
@@ -313,13 +315,6 @@ ges_base_xml_formatter_set_timeline_properties(GESBaseXmlFormatter * self,
 					       const gchar *properties,
 					       const gchar *metadatas);
 
-
-/****************************************************
- *        GESCommandLineFormatter                   *
- ****************************************************/
-G_GNUC_INTERNAL GOptionGroup *
-_ges_command_line_formatter_get_option_group (void);
-
 /****************************************************
  *              GESContainer                        *
  ****************************************************/
@@ -336,6 +331,10 @@ G_GNUC_INTERNAL void              ges_clip_set_moving_from_layer  (GESClip *clip
 G_GNUC_INTERNAL GESTrackElement*  ges_clip_create_track_element   (GESClip *clip, GESTrackType type);
 G_GNUC_INTERNAL GList*            ges_clip_create_track_elements  (GESClip *clip, GESTrackType type);
 
+/****************************************************
+ *              GESLayer                            *
+ ****************************************************/
+G_GNUC_INTERNAL gboolean ges_layer_resync_priorities (GESLayer * layer);
 
 /****************************************************
  *              GESTrackElement                     *
