@@ -282,7 +282,7 @@ ges_meta_container_set_ ## name (GESMetaContainer *container,      \
  * ges_meta_container_set_boolean:
  * @container: Target container
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets the value of a given meta item
  *
@@ -402,7 +402,7 @@ CREATE_SETTER (string, const gchar *, G_TYPE_STRING, string)
  * ges_meta_container_set_meta:
  * @container: Target container
  * @meta_item: Name of the meta item to set
- * @value: Value to set
+ * @value: (allow-none): Value to set
  * Sets the value of a given meta item
  *
  * Return: %TRUE if the meta could be added, %FALSE otherwize
@@ -414,6 +414,15 @@ ges_meta_container_set_meta (GESMetaContainer * container,
   g_return_val_if_fail (GES_IS_META_CONTAINER (container), FALSE);
   g_return_val_if_fail (meta_item != NULL, FALSE);
 
+  if (value == NULL) {
+    GstStructure *structure = _meta_container_get_structure (container);
+    gst_structure_remove_field (structure, meta_item);
+
+    g_signal_emit (container, _signals[NOTIFY_SIGNAL], 0, meta_item, value);
+
+    return TRUE;
+  }
+
   if (_can_write_value (container, meta_item, G_VALUE_TYPE (value)) == FALSE)
     return FALSE;
 
@@ -426,8 +435,8 @@ ges_meta_container_set_meta (GESMetaContainer * container,
  *
  * Serializes a meta container to a string.
  *
- * Returns: a newly-allocated string, or NULL in case of an error. The
- *    string must be freed with g_free() when no longer needed.
+ * Returns: (nullable): a newly-allocated string, or NULL in case of an error.
+ * The string must be freed with g_free() when no longer needed.
  */
 gchar *
 ges_meta_container_metas_to_string (GESMetaContainer * container)
@@ -443,13 +452,12 @@ ges_meta_container_metas_to_string (GESMetaContainer * container)
 
 /**
  * ges_meta_container_add_metas_from_string:
- * @str: a string created with ges_meta_container_metas_to_string()
  * @container: Target container
+ * @str: a string created with ges_meta_container_metas_to_string()
  *
  * Deserializes a meta container.
  *
- * Returns: (transfer full): a new #GESMetaContainer, or NULL in case of an
- * error.
+ * Returns: TRUE on success, FALSE if there was an error.
  */
 gboolean
 ges_meta_container_add_metas_from_string (GESMetaContainer * container,
@@ -515,7 +523,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
@@ -530,7 +538,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
@@ -545,7 +553,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
@@ -560,7 +568,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
@@ -575,7 +583,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
@@ -590,7 +598,7 @@ CREATE_REGISTER_STATIC (boolean, gboolean, G_TYPE_BOOLEAN, boolean)
  * @container: Target container
  * @flags: The #GESMetaFlag to be used
  * @meta_item: Name of the meta item to set
- * @value: (allow-none): Value to set
+ * @value: Value to set
  *
  * Sets a static meta on @container. This method lets you define static
  * metadatas, which means that the type of the registered will be the only
