@@ -82,6 +82,7 @@ enum
   ASSET_ADDED_SIGNAL,
   ASSET_REMOVED_SIGNAL,
   MISSING_URI_SIGNAL,
+  ASSET_LOADING_SIGNAL,
   LAST_SIGNAL
 };
 
@@ -434,7 +435,7 @@ ges_project_class_init (GESProjectClass * klass)
 
   /**
    * GESProject::asset-added:
-   * @formatter: the #GESProject
+   * @project: the #GESProject
    * @asset: The #GESAsset that has been added to @project
    */
   _signals[ASSET_ADDED_SIGNAL] =
@@ -442,9 +443,21 @@ ges_project_class_init (GESProjectClass * klass)
       G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GESProjectClass, asset_added),
       NULL, NULL, g_cclosure_marshal_generic, G_TYPE_NONE, 1, GES_TYPE_ASSET);
 
+  /**
+   * GESProject::asset-loading:
+   * @project: the #GESProject
+   * @asset: The #GESAsset that started loading
+   *
+   * Since: 1.8
+   */
+  _signals[ASSET_LOADING_SIGNAL] =
+      g_signal_new ("asset-loading", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GESProjectClass, asset_loading),
+      NULL, NULL, g_cclosure_marshal_generic, G_TYPE_NONE, 1, GES_TYPE_ASSET);
+
   /**
    * GESProject::asset-removed:
-   * @formatter: the #GESProject
+   * @project: the #GESProject
    * @asset: The #GESAsset that has been removed from @project
    */
   _signals[ASSET_REMOVED_SIGNAL] =
@@ -582,7 +595,7 @@ ges_project_try_updating_id (GESProject * project, GESAsset * asset,
 
   if (new_id) {
     GST_DEBUG_OBJECT (project, "new id found: %s", new_id);
-    if (!ges_asset_set_proxy (asset, new_id)) {
+    if (!ges_asset_try_proxy (asset, new_id)) {
       g_free (new_id);
       new_id = NULL;
     }
@@ -620,6 +633,7 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, GESProject * project)
     return;
   }
 
+  ges_asset_set_proxy (NULL, asset);
   ges_project_add_asset (project, asset);
   if (asset)
     gst_object_unref (asset);
@@ -657,9 +671,11 @@ ges_project_add_loading_asset (GESProject * project, GType extractable_type,
 {
   GESAsset *asset;
 
-  if ((asset = ges_asset_cache_lookup (extractable_type, id)))
-    g_hash_table_insert (project->priv->loading_assets, g_strdup (id),
-        gst_object_ref (asset));
+  if ((asset = ges_asset_cache_lookup (extractable_type, id))) {
+    if (g_hash_table_insert (project->priv->loading_assets, g_strdup (id),
+            gst_object_ref (asset)))
+      g_signal_emit (project, _signals[ASSET_LOADING_SIGNAL], 0, asset);
+  }
 }
 
 /**************************************
@@ -716,7 +732,7 @@ ges_project_create_asset (GESProject * project, const gchar * id,
  * "asset-added" signal to get the asset when it finally gets added to
  * @project
  *
- * Returns: The newly created #GESAsset
+ * Returns: (transfer full) (nullable): The newly created #GESAsset or %NULL.
  */
 GESAsset *
 ges_project_create_asset_sync (GESProject * project, const gchar * id,
@@ -751,6 +767,10 @@ ges_project_create_asset_sync (GESProject * project, const gchar * id,
     if (asset) {
       retry = FALSE;
 
+      if ((!g_hash_table_lookup (project->priv->assets,
+                  ges_asset_get_id (asset))))
+        g_signal_emit (project, _signals[ASSET_LOADING_SIGNAL], 0, asset);
+
       if (possible_id) {
         g_free (possible_id);
         ges_uri_assets_validate_uri (id);
@@ -761,6 +781,9 @@ ges_project_create_asset_sync (GESProject * project, const gchar * id,
       GESAsset *tmpasset;
 
       tmpasset = ges_asset_cache_lookup (extractable_type, id);
+      g_signal_emit (project, _signals[ASSET_LOADING_SIGNAL], 0, tmpasset);
+      g_signal_emit (project, _signals[ERROR_LOADING_ASSET], 0, *error, id,
+          extractable_type);
       possible_id = ges_project_try_updating_id (project, tmpasset, *error);
 
       if (possible_id == NULL)
@@ -773,6 +796,9 @@ ges_project_create_asset_sync (GESProject * project, const gchar * id,
     }
   }
 
+  if (!ges_asset_get_proxy_target (asset))
+    ges_asset_set_proxy (NULL, asset);
+
   ges_project_add_asset (project, asset);
 
   return asset;
@@ -1033,7 +1059,7 @@ ges_project_load (GESProject * project, GESTimeline * timeline, GError ** error)
  *
  * Retrieve the uri that is currently set on @project
  *
- * Returns: The uri that is set on @project
+ * Returns: (transfer full) (nullable): a newly allocated string representing uri.
  */
 gchar *
 ges_project_get_uri (GESProject * project)
