@@ -182,10 +182,8 @@ ges_smart_adder_class_init (GESSmartAdderClass * klass)
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   /* FIXME Make sure the AdderClass doesn get destroy before ourself */
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&src_template));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_static_pad_template (element_class, &src_template);
+  gst_element_class_add_static_pad_template (element_class, &sink_template);
   gst_element_class_set_static_metadata (element_class, "GES Smart adder",
       "Generic/Audio",
       "Use adder making use of GES informations",
