@@ -250,8 +250,10 @@ ges_timeline_element_dispose (GObject * object)
 {
   GESTimelineElement *self = GES_TIMELINE_ELEMENT (object);
 
-  if (self->priv->children_props)
+  if (self->priv->children_props) {
     g_hash_table_unref (self->priv->children_props);
+    self->priv->children_props = NULL;
+  }
 
   g_clear_object (&self->priv->copied_from);
 }
@@ -364,6 +366,9 @@ ges_timeline_element_class_init (GESTimelineElementClass * klass)
    * GESTimelineElement:priority:
    *
    * The priority of the object.
+   *
+   * Setting GESTimelineElement priorities is deprecated
+   * as all priority management is done by GES itself now.
    */
   properties[PROP_PRIORITY] = g_param_spec_uint ("priority", "Priority",
       "The priority of the object", 0, G_MAXUINT, 0, G_PARAM_READWRITE);
@@ -879,6 +884,10 @@ ges_timeline_element_get_priority (GESTimelineElement * self)
  * @priority: the priority
  *
  * Sets the priority of the object within the containing layer
+ *
+ * Deprecated: All priority management is done by GES itself now.
+ * To set #GESEffect priorities #ges_clip_set_top_effect_index should
+ * be used.
  */
 void
 ges_timeline_element_set_priority (GESTimelineElement * self, guint32 priority)
@@ -1315,6 +1324,8 @@ ges_timeline_element_set_child_property_by_pspec (GESTimelineElement * self,
     goto not_found;
 
   g_object_set_property (child, pspec->name, value);
+  gst_object_unref (child);
+  g_param_spec_unref (pspec);
 
   return;
 
@@ -1493,6 +1504,7 @@ ges_timeline_element_set_child_property_valist (GESTimelineElement * self,
     g_object_set_property (child, pspec->name, &value);
 
     gst_object_unref (child);
+    g_param_spec_unref (pspec);
     g_value_unset (&value);
 
     name = va_arg (var_args, gchar *);
@@ -1509,6 +1521,8 @@ cant_copy:
     GST_WARNING_OBJECT (self, "error copying value %s in %p: %s", pspec->name,
         self, error);
 
+    gst_object_unref (child);
+    g_param_spec_unref (pspec);
     g_value_unset (&value);
     return;
   }
@@ -1574,6 +1588,7 @@ ges_timeline_element_get_child_property_valist (GESTimelineElement * self,
     g_value_init (&value, pspec->value_type);
     g_object_get_property (child, pspec->name, &value);
     gst_object_unref (child);
+    g_param_spec_unref (pspec);
 
     G_VALUE_LCOPY (&value, var_args, 0, &error);
     if (error)
