@@ -70,44 +70,32 @@ static void
 ges_title_clip_get_property (GObject * object, guint property_id,
     GValue * value, GParamSpec * pspec)
 {
+  GESTimelineElement *child, *tmpsrc = NULL;
   GESTitleClipPrivate *priv = GES_TITLE_CLIP (object)->priv;
 
+  if (!priv->track_titles)
+    child = tmpsrc = GES_TIMELINE_ELEMENT (ges_title_source_new ());
+  else
+    child = priv->track_titles->data;
+
   switch (property_id) {
+      /* Falltrough all over */
     case PROP_TEXT:
-      ges_track_element_get_child_property (priv->track_titles->data, "text",
-          value);
-      break;
     case PROP_FONT_DESC:
-      ges_track_element_get_child_property (priv->track_titles->data,
-          "font-desc", value);
-      break;
     case PROP_HALIGNMENT:
-      ges_track_element_get_child_property (priv->track_titles->data,
-          "halignment", value);
-      break;
     case PROP_VALIGNMENT:
-      ges_track_element_get_child_property (priv->track_titles->data,
-          "valignment", value);
-      break;
     case PROP_COLOR:
-      ges_track_element_get_child_property (priv->track_titles->data, "color",
-          value);
-      break;
     case PROP_BACKGROUND:
-      ges_track_element_get_child_property (priv->track_titles->data,
-          "foreground-color", value);
-      break;
     case PROP_XPOS:
-      ges_track_element_get_child_property (priv->track_titles->data, "xpos",
-          value);
-      break;
     case PROP_YPOS:
-      ges_track_element_get_child_property (priv->track_titles->data, "ypos",
-          value);
+      ges_timeline_element_get_child_property (child, pspec->name, value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
+
+  if (tmpsrc)
+    g_object_unref (tmpsrc);
 }
 
 static void
@@ -156,7 +144,9 @@ static void
 ges_title_clip_class_init (GESTitleClipClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  GESClipClass *timobj_class = GES_CLIP_CLASS (klass);
+  GESTimelineElementClass *timeline_element_class =
+      GES_TIMELINE_ELEMENT_CLASS (klass);
+  GESClipClass *clip_class = GES_CLIP_CLASS (klass);
   GESContainerClass *container_class = GES_CONTAINER_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GESTitleClipPrivate));
@@ -223,7 +213,8 @@ ges_title_clip_class_init (GESTitleClipClass * klass)
           G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS |
           GES_PARAM_NO_SERIALIZATION));
 
-  timobj_class->create_track_element = ges_title_clip_create_track_element;
+  clip_class->create_track_element = ges_title_clip_create_track_element;
+  timeline_element_class->set_inpoint = NULL;
 
   container_class->child_added = _child_added;
   container_class->child_removed = _child_removed;
@@ -664,6 +655,9 @@ _child_removed (GESContainer * container, GESTimelineElement * element)
     priv->track_titles = g_slist_remove (priv->track_titles, element);
     gst_object_unref (element);
   }
+
+  GES_CONTAINER_CLASS (ges_title_clip_parent_class)->child_removed (container,
+      element);
 }
 
 static void
@@ -676,6 +670,9 @@ _child_added (GESContainer * container, GESTimelineElement * element)
     priv->track_titles = g_slist_prepend (priv->track_titles,
         gst_object_ref (element));
   }
+
+  GES_CONTAINER_CLASS (ges_title_clip_parent_class)->child_added (container,
+      element);
 }
 
 static GESTrackElement *
@@ -697,8 +694,8 @@ ges_title_clip_create_track_element (GESClip * clip, GESTrackType type)
  *
  * Creates a new #GESTitleClip
  *
- * Returns: The newly created #GESTitleClip, or NULL if there was an
- * error.
+ * Returns: (transfer floating) (nullable): The newly created #GESTitleClip,
+ * or %NULL if there was an error.
  */
 GESTitleClip *
 ges_title_clip_new (void)
