@@ -21,7 +21,7 @@
 /**
  * SECTION:gestitlesource
  * @short_description: render stand-alone text titles
- * 
+ *
  * #GESTitleSource is a GESTimelineElement that implements the notion
  * of titles in GES.
  *
@@ -93,6 +93,9 @@
 #include "ges-title-source.h"
 #include "ges-video-test-source.h"
 
+#define DEFAULT_TEXT ""
+#define DEFAULT_FONT_DESC "Serif 36"
+
 G_DEFINE_TYPE (GESTitleSource, ges_title_source, GES_TYPE_VIDEO_SOURCE);
 
 struct _GESTitleSourcePrivate
@@ -125,8 +128,8 @@ static void ges_title_source_set_property (GObject * object, guint
 static GstElement *ges_title_source_create_source (GESTrackElement * self);
 
 static gboolean
-_lookup_child (GESTrackElement * object,
-    const gchar * prop_name, GstElement ** element, GParamSpec ** pspec)
+_lookup_child (GESTimelineElement * object,
+    const gchar * prop_name, GObject ** element, GParamSpec ** pspec)
 {
   gboolean res;
 
@@ -140,7 +143,7 @@ _lookup_child (GESTrackElement * object,
     clean_name = g_strdup (prop_name);
 
   res =
-      GES_TRACK_ELEMENT_CLASS (ges_title_source_parent_class)->lookup_child
+      GES_TIMELINE_ELEMENT_CLASS (ges_title_source_parent_class)->lookup_child
       (object, clean_name, element, pspec);
 
   g_free (clean_name);
@@ -153,15 +156,18 @@ ges_title_source_class_init (GESTitleSourceClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GESVideoSourceClass *source_class = GES_VIDEO_SOURCE_CLASS (klass);
-  GESTrackElementClass *track_element_class = GES_TRACK_ELEMENT_CLASS (klass);
+  GESTimelineElementClass *timeline_element_class =
+      GES_TIMELINE_ELEMENT_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GESTitleSourcePrivate));
 
   object_class->get_property = ges_title_source_get_property;
   object_class->set_property = ges_title_source_set_property;
   object_class->dispose = ges_title_source_dispose;
-  track_element_class->lookup_child = _lookup_child;
 
+  timeline_element_class->set_inpoint = NULL;
+  timeline_element_class->lookup_child = _lookup_child;
+  source_class->ABI.abi.disable_scale_in_compositor = TRUE;
   source_class->create_source = ges_title_source_create_source;
 }
 
@@ -171,8 +177,8 @@ ges_title_source_init (GESTitleSource * self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_TITLE_SOURCE, GESTitleSourcePrivate);
 
-  self->priv->text = NULL;
-  self->priv->font_desc = NULL;
+  self->priv->text = g_strdup (DEFAULT_TEXT);
+  self->priv->font_desc = g_strdup (DEFAULT_FONT_DESC);
   self->priv->text_el = NULL;
   self->priv->halign = DEFAULT_HALIGNMENT;
   self->priv->valign = DEFAULT_VALIGNMENT;
@@ -231,24 +237,21 @@ ges_title_source_set_property (GObject * object,
 static GstElement *
 ges_title_source_create_source (GESTrackElement * object)
 {
-  GstCaps *alphacaps;
-  GstElement *topbin, *background, *text, *capsfilter;
+  GstElement *topbin, *background, *text;
   GstPad *src, *pad;
 
   GESTitleSource *self = GES_TITLE_SOURCE (object);
   GESTitleSourcePrivate *priv = self->priv;
   const gchar *bg_props[] = { "pattern", "foreground-color", NULL };
   const gchar *text_props[] = { "text", "font-desc", "valignment", "halignment",
-    "color", "xpos", "ypos", "outline-color", "shaded-background", NULL
+    "color", "xpos", "ypos", "x-absolute", "y-absolute", "outline-color",
+    "shaded-background",
+    "text-x", "text-y", "text-width", "text-height", NULL
   };
 
   topbin = gst_bin_new ("titlesrc-bin");
   background = gst_element_factory_make ("videotestsrc", "titlesrc-bg");
-  capsfilter = gst_element_factory_make ("capsfilter", NULL);
 
-  alphacaps =
-      gst_caps_from_string ("video/x-raw, format={AYUV, AYUV64, ARGB, ARGB64}");
-  g_object_set (capsfilter, "caps", alphacaps, NULL);
   text = gst_element_factory_make ("textoverlay", "titlsrc-text");
   if (priv->text) {
     g_object_set (text, "text", priv->text, NULL);
@@ -268,11 +271,9 @@ ges_title_source_create_source (GESTrackElement * object)
   g_object_set (background, "foreground-color", (guint) self->priv->background,
       NULL);
 
-  gst_bin_add_many (GST_BIN (topbin), background, capsfilter, text, NULL);
+  gst_bin_add_many (GST_BIN (topbin), background, text, NULL);
 
-  gst_element_link_pads_full (background, "src", capsfilter, "sink",
-      GST_PAD_LINK_CHECK_NOTHING);
-  gst_element_link_pads_full (capsfilter, "src", text, "video_sink",
+  gst_element_link_pads_full (background, "src", text, "video_sink",
       GST_PAD_LINK_CHECK_NOTHING);
 
   pad = gst_element_get_static_pad (text, "src");
@@ -298,7 +299,7 @@ ges_title_source_create_source (GESTrackElement * object)
  * @self: the #GESTitleSource* to set text on
  * @text: the text to render. an internal copy of this text will be
  * made.
- * 
+ *
  * Sets the text this track element will render.
  *
  * Deprecated: use ges_track_element_get/set_children_properties on the
@@ -322,7 +323,7 @@ ges_title_source_set_text (GESTitleSource * self, const gchar * text)
  * ges_title_source_set_font_desc:
  * @self: the #GESTitleSource
  * @font_desc: the pango font description
- * 
+ *
  * Set the pango font description this source will use to render
  * the text.
  */
@@ -600,8 +601,8 @@ ges_title_source_get_ypos (GESTitleSource * source)
  *
  * Creates a new #GESTitleSource.
  *
- * Returns: The newly created #GESTitleSource, or %NULL if there was an
- * error.
+ * Returns: (transfer floating) (nullable): The newly created #GESTitleSource,
+ * or %NULL if there was an error.
  */
 GESTitleSource *
 ges_title_source_new (void)
