@@ -640,8 +640,8 @@ ges_track_class_init (GESTrackClass * klass)
   g_object_class_install_property (object_class, ARG_MIXING,
       properties[ARG_MIXING]);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&ges_track_src_pad_template));
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &ges_track_src_pad_template);
 
   /**
    * GESTrack::track-element-added:
