@@ -62,6 +62,21 @@
  *  <entry role="property_name"><link linkend="GESVideoSource--height">height</link></entry>
  *  <entry>The desired height for that source. Set to 0 if size is not mandatory, will be set to height of the current track.</entry>
  * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="GstDeinterlaceModes"><type>GstDeinterlaceModes</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--deinterlace-mode">deinterlace-mode</link></entry>
+ *  <entry>Deinterlace Mode</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="GstDeinterlaceFields"><type>GstDeinterlaceFields</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--deinterlace-fields">deinterlace-fields</link></entry>
+ *  <entry>Fields to use for deinterlacing</entry>
+ * </row>
+ * <row>
+ *  <entry role="property_type"><link linkend="GstDeinterlaceFieldLayout"><type>GstDeinterlaceFieldLayout</type></link></entry>
+ *  <entry role="property_name"><link linkend="GESVideoSource--deinterlace-tff">deinterlace-tff</link></entry>
+ *  <entry>Deinterlace top field first</entry>
+ * </row>
  * </tbody>
  * </tgroup>
  * </informaltable>
@@ -75,14 +90,14 @@
 #include "ges-track-element.h"
 #include "ges-video-source.h"
 #include "ges-layer.h"
-#include "gstframepositionner.h"
+#include "gstframepositioner.h"
 
 #define parent_class ges_video_source_parent_class
 G_DEFINE_ABSTRACT_TYPE (GESVideoSource, ges_video_source, GES_TYPE_SOURCE);
 
 struct _GESVideoSourcePrivate
 {
-  GstFramePositionner *positionner;
+  GstFramePositioner *positioner;
   GstElement *capsfilter;
 };
 
@@ -97,9 +112,8 @@ _set_priority (GESTimelineElement * element, guint32 priority)
   res = GES_TIMELINE_ELEMENT_CLASS (parent_class)->set_priority (element,
       priority);
 
-  if (res && self->priv->positionner)
-    g_object_set (self->priv->positionner, "zorder",
-        G_MAXUINT - priority, NULL);
+  if (res && self->priv->positioner)
+    g_object_set (self->priv->positioner, "zorder", G_MAXUINT - priority, NULL);
 
   return res;
 }
@@ -121,9 +135,11 @@ ges_video_source_create_element (GESTrackElement * trksrc)
   GstElement *queue = gst_element_factory_make ("queue", NULL);
   GESVideoSourceClass *source_class = GES_VIDEO_SOURCE_GET_CLASS (trksrc);
   GESVideoSource *self;
-  GstElement *positionner, *videoscale, *videorate, *capsfilter, *videoconvert,
+  GstElement *positioner, *videoscale, *videorate, *capsfilter, *videoconvert,
       *deinterlace;
-  const gchar *props[] = { "alpha", "posx", "posy", "width", "height", NULL };
+  const gchar *positioner_props[] =
+      { "alpha", "posx", "posy", "width", "height", NULL };
+  const gchar *deinterlace_props[] = { "mode", "fields", "tff", NULL };
 
   if (!source_class->create_source)
     return NULL;
@@ -132,10 +148,10 @@ ges_video_source_create_element (GESTrackElement * trksrc)
 
   self = (GESVideoSource *) trksrc;
 
-  /* That positionner will add metadata to buffers according to its
+  /* That positioner will add metadata to buffers according to its
      properties, acting like a proxy for our smart-mixer dynamic pads. */
-  positionner = gst_element_factory_make ("framepositionner", "frame_tagger");
-  g_object_set (positionner, "zorder",
+  positioner = gst_element_factory_make ("framepositioner", "frame_tagger");
+  g_object_set (positioner, "zorder",
       G_MAXUINT - GES_TIMELINE_ELEMENT_PRIORITY (self), NULL);
 
   videoscale =
@@ -147,10 +163,11 @@ ges_video_source_create_element (GESTrackElement * trksrc)
   capsfilter =
       gst_element_factory_make ("capsfilter", "track-element-capsfilter");
 
-  ges_frame_positionner_set_source_and_filter (GST_FRAME_POSITIONNER
-      (positionner), trksrc, capsfilter);
+  ges_frame_positioner_set_source_and_filter (GST_FRAME_POSITIONNER
+      (positioner), trksrc, capsfilter);
 
-  ges_track_element_add_children_props (trksrc, positionner, NULL, NULL, props);
+  ges_track_element_add_children_props (trksrc, positioner, NULL, NULL,
+      positioner_props);
 
   if (deinterlace == NULL) {
     post_missing_element_message (sub_element, "deinterlace");
@@ -160,35 +177,69 @@ ges_video_source_create_element (GESTrackElement * trksrc)
             "deinterlace"), ("deinterlacing won't work"));
     topbin =
         ges_source_create_topbin ("videosrcbin", sub_element, queue,
-        videoconvert, positionner, videoscale, videorate, capsfilter, NULL);
+        videoconvert, positioner, videoscale, videorate, capsfilter, NULL);
   } else {
+    ges_track_element_add_children_props (trksrc, deinterlace, NULL, NULL,
+        deinterlace_props);
     topbin =
         ges_source_create_topbin ("videosrcbin", sub_element, queue,
-        videoconvert, deinterlace, positionner, videoscale, videorate,
+        videoconvert, deinterlace, positioner, videoscale, videorate,
         capsfilter, NULL);
   }
 
-  self->priv->positionner = GST_FRAME_POSITIONNER (positionner);
-  self->priv->positionner->scale_in_compositor =
+  self->priv->positioner = GST_FRAME_POSITIONNER (positioner);
+  self->priv->positioner->scale_in_compositor =
       !GES_VIDEO_SOURCE_GET_CLASS (self)->ABI.abi.disable_scale_in_compositor;
   self->priv->capsfilter = capsfilter;
 
   return topbin;
 }
 
+static gboolean
+_lookup_child (GESTimelineElement * object,
+    const gchar * prop_name, GObject ** element, GParamSpec ** pspec)
+{
+  gboolean res;
+
+  gchar *clean_name;
+
+  if (!g_strcmp0 (prop_name, "deinterlace-fields"))
+    clean_name = g_strdup ("GstDeinterlace::fields");
+  else if (!g_strcmp0 (prop_name, "deinterlace-mode"))
+    clean_name = g_strdup ("GstDeinterlace::mode");
+  else if (!g_strcmp0 (prop_name, "deinterlace-tff"))
+    clean_name = g_strdup ("GstDeinterlace::tff");
+  else if (!g_strcmp0 (prop_name, "tff") ||
+      !g_strcmp0 (prop_name, "fields") || !g_strcmp0 (prop_name, "mode")) {
+    GST_DEBUG_OBJECT (object, "Not allowed to use GstDeinterlace %s"
+        " property without prefixing its name", prop_name);
+    return FALSE;
+  } else
+    clean_name = g_strdup (prop_name);
+
+  res =
+      GES_TIMELINE_ELEMENT_CLASS (ges_video_source_parent_class)->lookup_child
+      (object, clean_name, element, pspec);
+
+  g_free (clean_name);
+
+  return res;
+}
+
 static void
 ges_video_source_class_init (GESVideoSourceClass * klass)
 {
-  GESTrackElementClass *track_class = GES_TRACK_ELEMENT_CLASS (klass);
+  GESTrackElementClass *track_element_class = GES_TRACK_ELEMENT_CLASS (klass);
   GESTimelineElementClass *element_class = GES_TIMELINE_ELEMENT_CLASS (klass);
   GESVideoSourceClass *video_source_class = GES_VIDEO_SOURCE_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GESVideoSourcePrivate));
 
   element_class->set_priority = _set_priority;
+  element_class->lookup_child = _lookup_child;
 
-  track_class->nleobject_factorytype = "nlesource";
-  track_class->create_element = ges_video_source_create_element;
+  track_element_class->nleobject_factorytype = "nlesource";
+  track_element_class->create_element = ges_video_source_create_element;
   video_source_class->create_source = NULL;
 }
 
@@ -197,6 +248,6 @@ ges_video_source_init (GESVideoSource * self)
 {
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_VIDEO_SOURCE, GESVideoSourcePrivate);
-  self->priv->positionner = NULL;
+  self->priv->positioner = NULL;
   self->priv->capsfilter = NULL;
 }
