@@ -49,7 +49,8 @@ struct _GESVideoTransitionPrivate
   GESVideoStandardTransitionType pending_type;
 
   /* these enable video interpolation */
-  GstTimedValueControlSource *crossfade_control_source;
+  GstTimedValueControlSource *fade_in_control_source;
+  GstTimedValueControlSource *fade_out_control_source;
   GstTimedValueControlSource *smpte_control_source;
 
   /* so we can support changing between wipes */
@@ -65,7 +66,7 @@ struct _GESVideoTransitionPrivate
   gint pending_border_value;
   gboolean pending_inverted;
 
-  GstElement *positionner;
+  GstElement *positioner;
 };
 
 enum
@@ -117,9 +118,8 @@ _set_priority (GESTimelineElement * element, guint32 priority)
   res = GES_TIMELINE_ELEMENT_CLASS (parent_class)->set_priority (element,
       priority);
 
-  if (res && self->priv->positionner)
-    g_object_set (self->priv->positionner, "zorder",
-        G_MAXUINT - priority, NULL);
+  if (res && self->priv->positioner)
+    g_object_set (self->priv->positioner, "zorder", G_MAXUINT - priority, NULL);
 
   return res;
 }
@@ -189,7 +189,8 @@ ges_video_transition_init (GESVideoTransition * self)
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
       GES_TYPE_VIDEO_TRANSITION, GESVideoTransitionPrivate);
 
-  self->priv->crossfade_control_source = NULL;
+  self->priv->fade_in_control_source = NULL;
+  self->priv->fade_out_control_source = NULL;
   self->priv->smpte_control_source = NULL;
   self->priv->smpte = NULL;
   self->priv->mixer_sink = NULL;
@@ -227,9 +228,14 @@ ges_video_transition_dispose (GObject * object)
 
   GST_DEBUG ("disposing");
 
-  if (priv->crossfade_control_source) {
-    gst_object_unref (priv->crossfade_control_source);
-    priv->crossfade_control_source = NULL;
+  if (priv->fade_in_control_source) {
+    gst_object_unref (priv->fade_in_control_source);
+    priv->fade_in_control_source = NULL;
+  }
+
+  if (priv->fade_out_control_source) {
+    gst_object_unref (priv->fade_out_control_source);
+    priv->fade_out_control_source = NULL;
   }
 
   if (priv->smpte_control_source) {
@@ -330,13 +336,13 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   iconva = gst_element_factory_make ("videoconvert", "tr-csp-a");
   iconvb = gst_element_factory_make ("videoconvert", "tr-csp-b");
-  priv->positionner =
-      gst_element_factory_make ("framepositionner", "frame_tagger");
-  g_object_set (priv->positionner, "zorder",
+  priv->positioner =
+      gst_element_factory_make ("framepositioner", "frame_tagger");
+  g_object_set (priv->positioner, "zorder",
       G_MAXUINT - GES_TIMELINE_ELEMENT_PRIORITY (self), NULL);
   oconv = gst_element_factory_make ("videoconvert", "tr-csp-output");
 
-  gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, priv->positionner,
+  gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, priv->positioner,
       oconv, NULL);
 
   mixer = ges_smart_mixer_new (NULL);
@@ -354,8 +360,8 @@ ges_video_transition_create_element (GESTrackElement * object)
   g_object_set (priv->mixer_sinka, "zorder", 0, NULL);
   g_object_set (priv->mixer_sinkb, "zorder", 1, NULL);
 
-  fast_element_link (mixer, priv->positionner);
-  fast_element_link (priv->positionner, oconv);
+  fast_element_link (mixer, priv->positioner);
+  fast_element_link (priv->positioner, oconv);
 
   sinka_target = gst_element_get_static_pad (iconva, "sink");
   sinkb_target = gst_element_get_static_pad (iconvb, "sink");
@@ -375,7 +381,9 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   /* set up interpolation */
 
-  priv->crossfade_control_source =
+  priv->fade_out_control_source =
+      set_interpolation (GST_OBJECT (priv->mixer_sinka), priv, "alpha");
+  priv->fade_in_control_source =
       set_interpolation (GST_OBJECT (priv->mixer_sinkb), priv, "alpha");
   priv->smpte_control_source =
       set_interpolation (GST_OBJECT (priv->smpte), priv, "position");
@@ -435,28 +443,40 @@ ges_video_transition_update_control_source (GstTimedValueControlSource * ts,
   gst_timed_value_control_source_set (ts, duration, end_value);
 }
 
+static void
+ges_video_transition_update_control_sources (GESVideoTransition * self,
+        GESVideoStandardTransitionType type)
+{
+  GESVideoTransitionPrivate *priv = self->priv;
+  guint64 duration =
+      ges_timeline_element_get_duration (GES_TIMELINE_ELEMENT (self));
+
+  GST_LOG ("updating controller");
+  if (type == GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE) {
+    ges_video_transition_update_control_source
+        (priv->fade_in_control_source, duration, 0.0, 1.0);
+    ges_video_transition_update_control_source
+        (priv->fade_out_control_source, duration, 1.0, 0.0);
+    ges_video_transition_update_control_source (priv->smpte_control_source,
+        duration, 0.0, 0.0);
+  } else {
+    ges_video_transition_update_control_source
+        (priv->fade_in_control_source, duration, 1.0, 1.0);
+    ges_video_transition_update_control_source
+        (priv->fade_out_control_source, duration, 1.0, 1.0);
+    ges_video_transition_update_control_source (priv->smpte_control_source,
+        duration, 1.0, 0.0);
+  }
+  GST_LOG ("done updating controller");
+}
+
 static void
 ges_video_transition_duration_changed (GESTrackElement * object,
     guint64 duration)
 {
   GESVideoTransition *self = GES_VIDEO_TRANSITION (object);
-  GESVideoTransitionPrivate *priv = self->priv;
 
-  GST_LOG ("updating controller");
-
-  if (priv->type == GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE) {
-    ges_video_transition_update_control_source (priv->crossfade_control_source,
-        duration, 0.0, 1.0);
-    ges_video_transition_update_control_source (priv->smpte_control_source,
-        duration, 0.0, 0.0);
-  } else {
-    ges_video_transition_update_control_source (priv->crossfade_control_source,
-        duration, 1.0, 1.0);
-    ges_video_transition_update_control_source (priv->smpte_control_source,
-        duration, 1.0, 0.0);
-  }
-
-  GST_LOG ("done updating controller");
+  ges_video_transition_update_control_sources (self, self->priv->type);
 }
 
 static inline void
@@ -490,8 +510,6 @@ ges_video_transition_set_transition_type_internal (GESVideoTransition
     * self, GESVideoStandardTransitionType type)
 {
   GESVideoTransitionPrivate *priv = self->priv;
-  guint64 duration =
-      ges_timeline_element_get_duration (GES_TIMELINE_ELEMENT (self));
 
   GST_DEBUG ("%p %d => %d", self, priv->type, type);
 
@@ -501,21 +519,11 @@ ges_video_transition_set_transition_type_internal (GESVideoTransition
   }
 
   if (type == priv->type) {
-    GST_ERROR ("This type is already set on this transition\n");
+    GST_DEBUG ("%d type is already set on this transition\n", type);
     return TRUE;
   }
 
-  if (type == GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE) {
-    ges_video_transition_update_control_source (priv->crossfade_control_source,
-        duration, 0.0, 1.0);
-    ges_video_transition_update_control_source (priv->smpte_control_source,
-        duration, 0.0, 0.0);
-  } else {
-    ges_video_transition_update_control_source (priv->crossfade_control_source,
-        duration, 1.0, 1.0);
-    ges_video_transition_update_control_source (priv->smpte_control_source,
-        duration, 1.0, 0.0);
-  }
+  ges_video_transition_update_control_sources (self, type);
 
   priv->type = type;
 
