@@ -994,9 +994,15 @@ _save_children_properties (GString * str, GESTrackElement * trackelement)
     spec = pspecs[i];
 
     if (_can_serialize_spec (spec)) {
+      gchar *spec_name =
+          g_strdup_printf ("%s::%s", g_type_name (spec->owner_type),
+          spec->name);
+
       _init_value_from_spec_for_serialization (&val, spec);
       ges_track_element_get_child_property_by_pspec (trackelement, spec, &val);
-      gst_structure_set_value (structure, spec->name, &val);
+      gst_structure_set_value (structure, spec_name, &val);
+
+      g_free (spec_name);
       g_value_unset (&val);
     }
     g_param_spec_unref (spec);
@@ -1287,7 +1293,7 @@ _save_groups (GESXmlFormatter * self, GString * str, GESTimeline * timeline)
   GList *seen_groups = NULL;
 
   g_string_append (str, "      <groups>\n");
-  for (tmp = timeline_get_groups (timeline); tmp; tmp = tmp->next) {
+  for (tmp = ges_timeline_get_groups (timeline); tmp; tmp = tmp->next) {
     _save_group (self, str, &seen_groups, tmp->data);
   }
   g_string_append (str, "      </groups>\n");
