@@ -111,7 +111,8 @@ GST_START_TEST (test_get_effects_from_tl)
   assert_equals_int (g_list_length (GES_CONTAINER_CHILDREN (source)), 1);
   video_source = GES_CONTAINER_CHILDREN (source)->data;
   fail_unless (GES_IS_VIDEO_TEST_SOURCE (video_source));
-  assert_equals_int (_PRIORITY (video_source), MIN_NLE_PRIO);
+  assert_equals_int (_PRIORITY (video_source),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
 
   GST_DEBUG ("Create effect");
   effect = ges_effect_new ("agingtv");
@@ -127,17 +128,20 @@ GST_START_TEST (test_get_effects_from_tl)
           GES_TIMELINE_ELEMENT (effect)));
   fail_unless (ges_track_element_get_track (GES_TRACK_ELEMENT (effect)) ==
       track_video);
-  assert_equals_int (_PRIORITY (effect), MIN_NLE_PRIO + 0);
-  assert_equals_int (_PRIORITY (video_source), MIN_NLE_PRIO + 1);
+  assert_equals_int (_PRIORITY (effect), MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 0);
+  assert_equals_int (_PRIORITY (video_source),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 1);
 
   GST_DEBUG ("Adding effect 1");
   fail_unless (ges_container_add (GES_CONTAINER (source),
           GES_TIMELINE_ELEMENT (effect1)));
   fail_unless (ges_track_element_get_track (GES_TRACK_ELEMENT (effect1)) ==
       track_video);
-  assert_equals_int (_PRIORITY (effect), MIN_NLE_PRIO);
-  assert_equals_int (_PRIORITY (effect1), MIN_NLE_PRIO + 1);
-  assert_equals_int (_PRIORITY (video_source), MIN_NLE_PRIO + 2);
+  assert_equals_int (_PRIORITY (effect), MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (_PRIORITY (effect1),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 1);
+  assert_equals_int (_PRIORITY (video_source),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 2);
 
   GST_DEBUG ("Adding effect 2");
   fail_unless (ges_container_add (GES_CONTAINER (source),
@@ -241,7 +245,6 @@ GST_END_TEST;
 
 GST_START_TEST (test_priorities_clip)
 {
-  gint i;
   GList *effects, *tmp;
   GESTimeline *timeline;
   GESLayer *layer;
@@ -281,9 +284,11 @@ GST_START_TEST (test_priorities_clip)
   fail_unless (GES_IS_EFFECT (audio_effect));
   fail_unless (GES_IS_EFFECT (video_effect));
 
-  /* FIXME This is ridiculus, both effects should have the same priority (0) */
-  assert_equals_int (_PRIORITY (audio_effect), MIN_NLE_PRIO);
-  assert_equals_int (_PRIORITY (video_effect), MIN_NLE_PRIO + 1);
+  /* FIXME This is ridiculus, both effects should have the same priority */
+  assert_equals_int (_PRIORITY (audio_effect),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (_PRIORITY (video_effect),
+      MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 1);
   assert_equals_int (GES_CONTAINER_HEIGHT (effect_clip), 2);
 
   effect = ges_effect_new ("agingtv");
@@ -303,18 +308,23 @@ GST_START_TEST (test_priorities_clip)
 
   fail_unless (ges_clip_set_top_effect_priority (GES_CLIP (effect_clip),
           GES_BASE_EFFECT (effect1), 0));
-  assert_equals_int (_PRIORITY (effect), 3 + MIN_NLE_PRIO);
-  assert_equals_int (_PRIORITY (effect1), 0 + MIN_NLE_PRIO);
+  assert_equals_int (_PRIORITY (effect_clip), 1);
+
+  assert_equals_int (_PRIORITY (effect), 3 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (_PRIORITY (effect1),
+      0 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+
   assert_equals_int (GES_CONTAINER_HEIGHT (effect_clip), 4);
 
   fail_unless (ges_clip_set_top_effect_priority (GES_CLIP (effect_clip),
           GES_BASE_EFFECT (effect1), 3));
-  assert_equals_int (_PRIORITY (effect), 2 + MIN_NLE_PRIO);
-  assert_equals_int (_PRIORITY (effect1), 3 + MIN_NLE_PRIO);
+  assert_equals_int (_PRIORITY (effect), 2 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (_PRIORITY (effect1),
+      3 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
   assert_equals_int (GES_CONTAINER_HEIGHT (effect_clip), 4);
 
   effects = ges_clip_get_top_effects (GES_CLIP (effect_clip));
-  for (tmp = effects, i = 0; tmp; tmp = tmp->next, i++) {
+  for (tmp = effects; tmp; tmp = tmp->next) {
     gint priority = ges_clip_get_top_effect_position (GES_CLIP (effect_clip),
         GES_BASE_EFFECT (tmp->data));
     fail_unless (priority > effect_prio);
@@ -325,15 +335,13 @@ GST_START_TEST (test_priorities_clip)
   }
   g_list_free (effects);
 
-  ges_timeline_element_set_priority (GES_TIMELINE_ELEMENT (effect_clip), 2);
-  assert_equals_int (_PRIORITY (effect_clip), 2);
   assert_equals_int (GES_CONTAINER_HEIGHT (effect_clip), 4);
   effects = ges_clip_get_top_effects (GES_CLIP (effect_clip));
   effect_prio = 0;
-  for (tmp = effects, i = 0; tmp; tmp = tmp->next, i++) {
+  for (tmp = effects; tmp; tmp = tmp->next) {
     gint priority = ges_clip_get_top_effect_position (GES_CLIP (effect_clip),
         GES_BASE_EFFECT (tmp->data));
-    fail_unless (priority > effect_prio);
+    fail_unless (priority >= effect_prio, "%d >= %d", priority, effect_prio);
     fail_unless (GES_IS_EFFECT (tmp->data));
     effect_prio = priority;
 
@@ -491,6 +499,62 @@ GST_START_TEST (test_clip_signals)
 }
 
 GST_END_TEST;
+
+GST_START_TEST (test_split_clip_effect_priorities)
+{
+  GESLayer *layer;
+  GESTimeline *timeline;
+  GESTrack *track_video;
+  GESClip *clip, *nclip;
+  GESEffect *effect;
+  GESTrackElement *source, *nsource, *neffect;
+
+  ges_init ();
+
+  timeline = ges_timeline_new ();
+  layer = ges_layer_new ();
+  track_video = GES_TRACK (ges_video_track_new ());
+
+  g_object_set (timeline, "auto-transition", TRUE, NULL);
+  ges_timeline_add_track (timeline, track_video);
+  ges_timeline_add_layer (timeline, layer);
+
+  GST_DEBUG ("Create effect");
+  effect = ges_effect_new ("agingtv");
+  clip = GES_CLIP (ges_test_clip_new ());
+  g_object_set (clip, "duration", GST_SECOND * 2, NULL);
+
+  fail_unless (ges_container_add (GES_CONTAINER (clip),
+          GES_TIMELINE_ELEMENT (effect)));
+  ges_layer_add_clip (layer, clip);
+
+  source = ges_clip_find_track_element (clip, NULL, GES_TYPE_VIDEO_SOURCE);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (effect), 3);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (source), 4);
+
+  nclip = ges_clip_split (clip, GST_SECOND);
+  neffect = ges_clip_find_track_element (nclip, NULL, GES_TYPE_EFFECT);
+  nsource = ges_clip_find_track_element (nclip, NULL, GES_TYPE_VIDEO_SOURCE);
+
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (effect), 3);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (source), 4);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (neffect), 5);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (nsource), 6);
+
+  /* Create a transition ... */
+  ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (clip), GST_SECOND / 2);
+
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (effect), 3);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (source), 4);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (neffect), 5);
+  assert_equals_uint64 (GES_TIMELINE_ELEMENT_PRIORITY (nsource), 6);
+
+  gst_object_unref (timeline);
+}
+
+GST_END_TEST;
+
+
 static Suite *
 ges_suite (void)
 {
@@ -506,6 +570,7 @@ ges_suite (void)
   tcase_add_test (tc_chain, test_priorities_clip);
   tcase_add_test (tc_chain, test_effect_set_properties);
   tcase_add_test (tc_chain, test_clip_signals);
+  tcase_add_test (tc_chain, test_split_clip_effect_priorities);
 
   return s;
 }
