@@ -72,34 +72,34 @@ GST_START_TEST (test_layer_properties)
   assert_equals_uint64 (_START (clip), 42);
   assert_equals_uint64 (_DURATION (clip), 51);
   assert_equals_uint64 (_INPOINT (clip), 12);
-  assert_equals_uint64 (_PRIORITY (clip), 0);
+  assert_equals_uint64 (_PRIORITY (clip), 1);
   ges_timeline_commit (timeline);
   nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
-      51, MIN_NLE_PRIO, TRUE);
+      51, MIN_NLE_PRIO + TRANSITIONS_HEIGHT, TRUE);
 
   /* Change the priority of the layer */
   g_object_set (layer, "priority", 1, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 1);
-  assert_equals_uint64 (_PRIORITY (clip), 0);
+  assert_equals_uint64 (_PRIORITY (clip), 1);
   ges_timeline_commit (timeline);
   nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
-      51, LAYER_HEIGHT + MIN_NLE_PRIO, TRUE);
+      51, LAYER_HEIGHT + MIN_NLE_PRIO + TRANSITIONS_HEIGHT, TRUE);
 
   /* Change it to an insanely high value */
   g_object_set (layer, "priority", 31, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 31);
-  assert_equals_uint64 (_PRIORITY (clip), 0);
+  assert_equals_uint64 (_PRIORITY (clip), 1);
   ges_timeline_commit (timeline);
   nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
-      51, MIN_NLE_PRIO + LAYER_HEIGHT * 31, TRUE);
+      51, MIN_NLE_PRIO + TRANSITIONS_HEIGHT + LAYER_HEIGHT * 31, TRUE);
 
   /* and back to 0 */
   g_object_set (layer, "priority", 0, NULL);
   assert_equals_int (ges_layer_get_priority (layer), 0);
-  assert_equals_uint64 (_PRIORITY (clip), 0);
+  assert_equals_uint64 (_PRIORITY (clip), 1);
   ges_timeline_commit (timeline);
   nle_object_check (ges_track_element_get_nleobject (trackelement), 42, 51, 12,
-      51, MIN_NLE_PRIO + 0, TRUE);
+      51, MIN_NLE_PRIO + TRANSITIONS_HEIGHT + 0, TRUE);
 
   gst_object_unref (trackelement);
   fail_unless (ges_layer_remove_clip (layer, clip));
@@ -119,7 +119,7 @@ GST_START_TEST (test_layer_priorities)
   GESClip *clip1, *clip2, *clip3;
   GstElement *nleobj1, *nleobj2, *nleobj3;
   guint prio1, prio2, prio3;
-  GList *objs, *tmp;
+  GList *objs;
 
   ges_init ();
 
@@ -144,25 +144,15 @@ GST_START_TEST (test_layer_priorities)
   fail_unless (ges_timeline_add_track (timeline, track));
 
   clip1 = GES_CLIP (ges_test_clip_new ());
-  ges_clip_set_supported_formats (clip1,
-      GES_TRACK_TYPE_AUDIO | GES_TRACK_TYPE_VIDEO);
   clip2 = GES_CLIP (ges_test_clip_new ());
-  ges_clip_set_supported_formats (clip2,
-      GES_TRACK_TYPE_AUDIO | GES_TRACK_TYPE_VIDEO);
   clip3 = GES_CLIP (ges_test_clip_new ());
-  ges_clip_set_supported_formats (clip3,
-      GES_TRACK_TYPE_AUDIO | GES_TRACK_TYPE_VIDEO);
   fail_unless (clip1 != NULL);
   fail_unless (clip2 != NULL);
   fail_unless (clip3 != NULL);
 
-  /* Set priorities on the objects */
-  g_object_set (clip1, "priority", 0, NULL);
-  assert_equals_int (_PRIORITY (clip1), 0);
-  g_object_set (clip2, "priority", 1, NULL);
-  assert_equals_int (_PRIORITY (clip2), 1);
-  g_object_set (clip3, "priority", LAYER_HEIGHT + 1, NULL);
-  assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT + 1);
+  g_object_set (clip1, "start", 0, "duration", 10, NULL);
+  g_object_set (clip2, "start", 10, "duration", 10, NULL);
+  g_object_set (clip3, "start", 20, "duration", 10, NULL);
 
   /* Add objects to the timeline */
   fail_unless (ges_layer_add_clip (layer1, clip1));
@@ -178,11 +168,11 @@ GST_START_TEST (test_layer_priorities)
   fail_unless (trackelement3 != NULL);
 
   ges_timeline_commit (timeline);
-  assert_equals_int (_PRIORITY (clip1), 0);
+  assert_equals_int (_PRIORITY (clip1), 1);
   nleobj1 = ges_track_element_get_nleobject (trackelement1);
   fail_unless (nleobj1 != NULL);
   g_object_get (nleobj1, "priority", &prio1, NULL);
-  assert_equals_int (prio1, MIN_NLE_PRIO);
+  assert_equals_int (prio1, MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
 
   assert_equals_int (_PRIORITY (clip2), 1);
   nleobj2 = ges_track_element_get_nleobject (trackelement2);
@@ -191,13 +181,16 @@ GST_START_TEST (test_layer_priorities)
   /* clip2 is on the second layer and has a priority of 1 */
   assert_equals_int (prio2, MIN_NLE_PRIO + LAYER_HEIGHT + 1);
 
-  assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
+  /* We do not take into account users set priorities */
+  assert_equals_int (_PRIORITY (clip3), 1);
+
   nleobj3 = ges_track_element_get_nleobject (trackelement3);
   fail_unless (nleobj3 != NULL);
+
   /* clip3 is on the third layer and has a priority of LAYER_HEIGHT + 1
    * it priority must have the maximum priority of this layer*/
   g_object_get (nleobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio3, MIN_NLE_PRIO + LAYER_HEIGHT * 3 - 1);
+  assert_equals_int (prio3, 1 + MIN_NLE_PRIO + LAYER_HEIGHT * 2);
 
   /* Move layers around */
   g_object_set (layer1, "priority", 2, NULL);
@@ -209,15 +202,16 @@ GST_START_TEST (test_layer_priorities)
   assert_equals_int (ges_layer_get_priority (layer1), 2);
   assert_equals_int (ges_layer_get_priority (layer2), 0);
   assert_equals_int (ges_layer_get_priority (layer3), 1);
-  assert_equals_int (_PRIORITY (clip1), 0);
+  assert_equals_int (_PRIORITY (clip1), 1);
   assert_equals_int (_PRIORITY (clip2), 1);
-  assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
+  assert_equals_int (_PRIORITY (clip3), 1);
   g_object_get (nleobj1, "priority", &prio1, NULL);
   g_object_get (nleobj2, "priority", &prio2, NULL);
   g_object_get (nleobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_NLE_PRIO);
+  assert_equals_int (prio1,
+      2 * LAYER_HEIGHT + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
   assert_equals_int (prio2, MIN_NLE_PRIO + 1);
-  assert_equals_int (prio3, LAYER_HEIGHT * 2 - 1 + MIN_NLE_PRIO);
+  assert_equals_int (prio3, LAYER_HEIGHT + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
 
   /* And move objects around */
   fail_unless (ges_clip_move_to_layer (clip2, layer1));
@@ -228,33 +222,21 @@ GST_START_TEST (test_layer_priorities)
   assert_equals_int (g_list_length (objs), 3);
   fail_unless (ges_layer_get_clips (layer2) == NULL);
   fail_unless (ges_layer_get_clips (layer3) == NULL);
-
-  for (tmp = objs; tmp; tmp = g_list_next (tmp)) {
-    gst_object_unref (tmp->data);
-  }
-  g_list_free (objs);
+  g_list_free_full (objs, gst_object_unref);
 
   /*  Check their priorities (layer1 priority is now 2) */
-  assert_equals_int (_PRIORITY (clip1), 0);
-  assert_equals_int (_PRIORITY (clip2), 1);
-  assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1);
+  assert_equals_int (_PRIORITY (clip1), 1);
+  assert_equals_int (_PRIORITY (clip2), 2);
+  assert_equals_int (_PRIORITY (clip3), 3);
   g_object_get (nleobj1, "priority", &prio1, NULL);
   g_object_get (nleobj2, "priority", &prio2, NULL);
   g_object_get (nleobj3, "priority", &prio3, NULL);
-  assert_equals_int (prio1, 2 * LAYER_HEIGHT + MIN_NLE_PRIO);
-  assert_equals_int (prio2, 2 * LAYER_HEIGHT + 1 + MIN_NLE_PRIO);
-  assert_equals_int (prio3, LAYER_HEIGHT * 3 - 1 + MIN_NLE_PRIO);
-
-  /* And change TrackElement-s priorities and check that changes are not
-   * refected on it containing Clip
-   * FIXME : We should rework the way we handle the case were a trackobject
-   * prio is set outside the layer it is in.
-   * ges_timeline_element_set_priority (GES_TIMELINE_ELEMENT (trackelement3),
-   * ges_timeline_commit (timeline);
-   *     LAYER_HEIGHT * 2);
-   * g_object_get (nleobj3, "priority", &prio3, NULL);
-   * assert_equals_int (prio3, 2 * LAYER_HEIGHT);
-   * assert_equals_int (_PRIORITY (clip3), LAYER_HEIGHT - 1); */
+  assert_equals_int (prio1,
+      2 * LAYER_HEIGHT + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (prio2,
+      2 * LAYER_HEIGHT + 1 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
+  assert_equals_int (prio3,
+      2 * LAYER_HEIGHT + 2 + MIN_NLE_PRIO + TRANSITIONS_HEIGHT);
 
   gst_object_unref (trackelement1);
   gst_object_unref (trackelement2);
@@ -1142,11 +1124,12 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   GST_DEBUG ("Ripple src1 to 700");
   ges_container_edit (GES_CONTAINER (src1), NULL, 0,
       GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 700);
+
   /*                                           1700___________src_________2700
    *                                           1700__tr__2000
    *                700___________src1_________1700
-   *                         1000___________src3_________2000   Layer
-   *                         1000______tr______1700
+   *                                1200___________src3_________2200   Layer
+   *                                1200___tr__1700
    *---------------------------------------------------------------------------
    * 0__________src2_________1000                               Layer1
    */
@@ -1157,8 +1140,8 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   assert_equals_uint64 (_DURATION (src1), 1700 - 700);
   assert_equals_uint64 (_START (src2), 0);
   assert_equals_uint64 (_DURATION (src2), 1000);
-  assert_equals_uint64 (_START (src3), 1000);
-  assert_equals_uint64 (_DURATION (src3), 2000 - 1000);
+  assert_equals_uint64 (_START (src3), 1200);
+  assert_equals_uint64 (_DURATION (src3), 2200 - 1200);
 
   GST_DEBUG ("Checking transitions on first layer");
   current = objects = ges_layer_get_clips (layer);
@@ -1168,14 +1151,14 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   current = current->next;
   transition = current->data;
   assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1700 - 1000);
+  assert_equals_uint64 (_START (transition), 1200);
+  assert_equals_uint64 (_DURATION (transition), 1700 - 1200);
 
   current = current->next;
   transition = current->data;
   assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
-  assert_equals_uint64 (_START (transition), 1000);
-  assert_equals_uint64 (_DURATION (transition), 1700 - 1000);
+  assert_equals_uint64 (_START (transition), 1200);
+  assert_equals_uint64 (_DURATION (transition), 1700 - 1200);
 
   current = current->next;
   fail_unless (current->data == src3);
@@ -1184,13 +1167,13 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   transition = current->data;
   assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
   assert_equals_uint64 (_START (transition), 1700);
-  assert_equals_uint64 (_DURATION (transition), 2000 - 1700);
+  assert_equals_uint64 (_DURATION (transition), 2200 - 1700);
 
   current = current->next;
   transition = current->data;
   assert_is_type (transition, GES_TYPE_TRANSITION_CLIP);
   assert_equals_uint64 (_START (transition), 1700);
-  assert_equals_uint64 (_DURATION (transition), 2000 - 1700);
+  assert_equals_uint64 (_DURATION (transition), 2200 - 1700);
 
   current = current->next;
   fail_unless (current->data == src);
