@@ -146,6 +146,7 @@ static void
 _project_loaded_cb (GESProject * project, GESTimeline * timeline,
     GESLauncher * self)
 {
+  gchar *project_uri = NULL;
   ParsedOptions *opts = &self->priv->parsed_options;
   GST_INFO ("Project loaded, playing it");
 
@@ -174,9 +175,10 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
     }
   }
 
-  _timeline_set_user_options (self, timeline, ges_project_get_uri (project));
+  project_uri = ges_project_get_uri (project);
+  _timeline_set_user_options (self, timeline, project_uri);
 
-  if (self->priv->parsed_options.load_path && ges_project_get_uri (project)
+  if (self->priv->parsed_options.load_path && project_uri
       && ges_validate_activate (GST_PIPELINE (self->priv->pipeline),
           opts->scenario, &opts->needs_set_state) == FALSE) {
     g_error ("Could not activate scenario %s", opts->scenario);
@@ -184,6 +186,8 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
     g_application_quit (G_APPLICATION (self));
   }
 
+  g_free (project_uri);
+
   if (!self->priv->seenerrors && opts->needs_set_state &&
       gst_element_set_state (GST_ELEMENT (self->priv->pipeline),
           GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
@@ -288,7 +292,7 @@ bus_message_cb (GstBus * bus, GstMessage * message, GESLauncher * self)
       g_printerr ("ERROR from element %s: %s\n", GST_OBJECT_NAME (message->src),
           err->message);
       g_printerr ("Debugging info: %s\n", (dbg_info) ? dbg_info : "none");
-      g_error_free (err);
+      g_clear_error (&err);
       g_free (dbg_info);
       self->priv->seenerrors = TRUE;
       g_application_quit (G_APPLICATION (self));
@@ -733,7 +737,7 @@ _local_command_line (GApplication * application, gchar ** arguments[],
 
   if (!g_application_register (application, NULL, &error)) {
     *exit_status = 1;
-    g_error_free (error);
+    g_clear_error (&error);
     return FALSE;
   }
 
@@ -793,6 +797,7 @@ _shutdown (GApplication * application)
 {
   gint validate_res = 0;
   GESLauncher *self = GES_LAUNCHER (application);
+  ParsedOptions *opts = &self->priv->parsed_options;
 
   _save_timeline (self);
 
@@ -808,6 +813,8 @@ _shutdown (GApplication * application)
   g_source_remove (self->priv->signal_watch_id);
 #endif
 
+  g_free (opts->sanitized_timeline);
+
   G_APPLICATION_CLASS (ges_launcher_parent_class)->shutdown (application);
 }
 
